#!/usr/bin/env bash

# Check that input file was given
if [[ $# -ne 1 ]] ;
then
 echo " Useage: $0 file.fq "
 exit
fi

# Setup software with BioGrids
#  Download and install biogrids CLI client then run:
#  
#  biogrids activate <site name>  <user name>  <activation key>
#
# Examples: 
#
# --- Linux ----
# curl -kLO https://biogrids.org/wiki/downloads/biogrids-1.0.694-Linux.tgz
# tar zxf biogrids-1.0.694-Linux.tgz
# cd biogrids-1.0.694-Linux
#
#
# --- OSX ---
#  curl -kLO https://biogrids.org/wiki/downloads/biogrids-1.0.694-Darwin.tgz
#  tar zxf biogrids-1.0.694-Darwin.tgz
#  cd biogrids-1.0.694-Darwin
#
# --- Run biogrids ---
#  ./biogrids activate biogrid-production jvincent1  70rYFBTDnmCr93VUklfbf1s3M4jdyC9bFVYHew==
#  ./biogrids install fastqc trimmomatic samtools star subread igv
#
# Change back to parent directory
#  cd ..
# -------------------------

# Invoke the BioGrids environment 
# source /programs/biogrids.shrc

# get input fastq file given when invoking this script
fastq_infile=${1}
base=`basename ${fastq_infile} .fq`
echo "Sample name is $base"           

# set project base directory
base_dir="./"

# set runtime options and inputs
cores=2
genome=${base_dir}/reference_data/
genome_fasta=${base_dir}/reference_data/chr1_MOV10.fa
gtf=${base_dir}/reference_data/chr1_MOV10.gtf

# output dir names
fastqc_out_dir="${base_dir}/results/fastqc/"
align_out_dir="${base_dir}/results/STAR"
counts_out_dir="${base_dir}/results/counts"

# create output dirs if they do not already exist
mkdir -p ${fastqc_out_dir}
mkdir -p ${align_out_dir}
mkdir -p ${counts_out_dir}

# set locations of output for programs
fastqc_out=${fastqc_out_dir}
align_out=${align_out_dir}/${base}_
counts_input_bam=${align_out_dir}/${base}_Aligned.sortedByCoord.out.bam
counts=${counts_out_dir}/${base}_featurecounts.txt

# Run FastQC 
fastqc -o ${fastqc_out_dir} --extract -f fastq ${fastq_infile} 

# Run STAR
STAR --runThreadN ${cores} --genomeDir ${genome} -genomeFastaFiles ${genome_fasta}   --readFilesIn ${fastq_infile} --outFileNamePrefix ${align_out} --outFilterMultimapNmax 10 --outSAMstrandField intronMotif --outReadsUnmapped Fastx --outSAMtype BAM SortedByCoordinate --limitBAMsortRAM 1004040941 --outSAMunmapped Within --outSAMattributes NH HI NM MD AS

# Create BAM index
samtools index ${counts_input_bam}

# Count mapped reads
featureCounts -T ${cores} -a ${gtf} -o ${counts} ${counts_input_bam}

